# Endpoints

```{eval-rst}

.. automodule:: torii_usb.usb.usb3.endpoints
	:members:

```

## Control

```{eval-rst}

.. automodule:: torii_usb.usb.usb3.endpoints.control
	:members:

```

## Stream

```{eval-rst}

.. automodule:: torii_usb.usb.usb3.endpoints.stream
	:members:

```
